@@ -17,18 +17,15 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-
 Important notes:
 
 - We hereby ask people using this source NOT to use it in purpose of grabbing
 emails addresses, or collecting any other private information on persons.
 This would disgrace our work, and spoil the many hours we spent on it.
 
-
 Please visit our Website: http://www.httrack.com
 */
 
-
 /* ------------------------------------------------------------ */
 /* File: htsparse.h parser                                      */
 /*       html/javascript/css parser                             */
@@ -58,29 +55,29 @@ typedef struct htsmoduleStructExtended htsmoduleStructExtended;
 #endif
 struct htsmoduleStructExtended {
   /* Main object */
-  htsblk* r_;
+  htsblk *r_;
 
   /* Error handling */
-  int* error_;
-  int* exit_xh_;
-  int* store_errpage_;
+  int *error_;
+  int *exit_xh_;
+  int *store_errpage_;
 
   /* Structural */
-  int* filptr_;
-  char*** filters_;
-  robots_wizard* robots_;
-  hash_struct* hash_;
-  int* lien_max_;
+  int *filptr_;
+  char ***filters_;
+  robots_wizard *robots_;
+  hash_struct *hash_;
+  int *lien_max_;
 
   /* Base & codebase */
-  char* base;
-  char* codebase;
+  char *base;
+  char *codebase;
 
   /* Index */
-  int* makeindex_done_;
-  FILE** makeindex_fp_;
-  int* makeindex_links_;
-  char* makeindex_firstlink_;
+  int *makeindex_done_;
+  FILE **makeindex_fp_;
+  int *makeindex_links_;
+  char *makeindex_firstlink_;
 
   /* Html templates */
   char *template_header_;
@@ -88,21 +85,20 @@ struct htsmoduleStructExtended {
   char *template_footer_;
 
   /* Specific to downloads */
-  LLint* stat_fragment_;
+  LLint *stat_fragment_;
   TStamp makestat_time;
-  FILE* makestat_fp;
-  LLint* makestat_total_;
-  int* makestat_lnk_;
-  FILE* maketrack_fp;
+  FILE *makestat_fp;
+  LLint *makestat_total_;
+  int *makestat_lnk_;
+  FILE *maketrack_fp;
 
   /* Function-dependant */
-  char* loc_;
-  TStamp* last_info_shell_;
-  int* info_shell_;
+  char *loc_;
+  TStamp *last_info_shell_;
+  int *info_shell_;
 
 };
 
-
 /* Library internal definictions */
 #ifdef HTS_INTERNAL_BYTECODE
 
@@ -110,7 +106,7 @@ struct htsmoduleStructExtended {
   Main parser, attempt to scan links inside the html/css/js file
   Parameters: The public module structure, and the private module variables
 */
-int htsparse(htsmoduleStruct* str, htsmoduleStructExtended* stre);
+int htsparse(htsmoduleStruct * str, htsmoduleStructExtended * stre);
 
 /*
   Check for 301,302.. errors ("moved") and handle them; re-isuue requests, make
@@ -118,30 +114,31 @@ int htsparse(htsmoduleStruct* str, htsmoduleStructExtended* stre);
   Parameters: The public module structure, and the private module variables
   Returns 0 upon success
 */
-int hts_mirror_check_moved(htsmoduleStruct* str, htsmoduleStructExtended* stre);
+int hts_mirror_check_moved(htsmoduleStruct * str,
+                           htsmoduleStructExtended * stre);
 
 /*
   Process user intercations: pause, add link, delete link..
 */
-void hts_mirror_process_user_interaction(htsmoduleStruct* str, htsmoduleStructExtended* stre);
+void hts_mirror_process_user_interaction(htsmoduleStruct * str,
+                                         htsmoduleStructExtended * stre);
 
 /*
   Get the next file on the queue, waiting for it, handling other files in background..
   Parameters: The public module structure, and the private module variables
   Returns 0 upon success
 */
-int hts_mirror_wait_for_next_file(htsmoduleStruct* str, htsmoduleStructExtended* stre);
+int hts_mirror_wait_for_next_file(htsmoduleStruct * str,
+                                  htsmoduleStructExtended * stre);
 
 /*
   Wait for (adr, fil, save) to be started, that is, 
   to be ready for naming, having its header MIME type
   If the final URL is to be forbidden, sets 'forbidden_url' to the corresponding value
 */
-int hts_wait_delayed(htsmoduleStruct* str, 
-                     char* adr, char* fil, char* save, 
-                     char* parent_adr, char* parent_fil,
-                     char* former_adr, char* former_fil, 
-                     int* forbidden_url);
+int hts_wait_delayed(htsmoduleStruct * str, char *adr, char *fil, char *save,
+                     char *parent_adr, char *parent_fil, char *former_adr,
+                     char *former_fil, int *forbidden_url);
 
 /* Context state */
 
